@@ -301,8 +301,6 @@ class SDM:
         log.debug("current training data %d items.",
                   len(current_training_data))
         log.debug("Generated data %d items.", len(train_data))
-        log.debug(current_training_data[0])
-        log.debug(train_data[0])
 
         total_train_data = pd.DataFrame(train_data + current_training_data,
                                         columns=self.column_names)
