@@ -9,4 +9,4 @@ def split(df, test_ratio=0.3):
     train = df[~msk]
     train.drop("split", axis=1, inplace=True)
     test.drop("split", axis=1, inplace=True)
-    return train, test
+    return list(train.T.to_dict().values()), list(test.T.to_dict().values())
